Type: Package
Package: loo
Title: Efficient Leave-One-Out Cross-Validation and WAIC for Bayesian
        Models
Version: 2.10.0
Date: 2026-06-24
Authors@R: c(
    person("Aki", "Vehtari", email = "Aki.Vehtari@aalto.fi", role = "aut"),
    person("Jonah", "Gabry", email = "jgabry@gmail.com", role = c("cre", "aut")),
    person("Måns", "Magnusson", role = "aut"),
    person("Yuling", "Yao", role = "aut"),
    person("Paul-Christian", "Bürkner", role = "aut"),
    person("Topi", "Paananen", role = "aut"),
    person("Andrew", "Gelman", role = "aut"),
    person("Ben", "Goodrich", role = "ctb"),
    person("Juho", "Piironen", role = "ctb"),
    person("Bruno", "Nicenboim", role = "ctb"),
    person("Leevi", "Lindgren", role = "ctb"),
    person("Visruth", "Srimath Kandali", role = "ctb"),
    person("Florence", "Bockting", role = "ctb")
  )
Maintainer: Jonah Gabry <jgabry@gmail.com>
Description: Efficient approximate leave-one-out cross-validation (LOO)
    for Bayesian models fit using Markov chain Monte Carlo, as described
    in Vehtari, Gelman, and Gabry (2017) <doi:10.1007/s11222-016-9696-4>.
    The approximation uses Pareto smoothed importance sampling (PSIS), a
    new procedure for regularizing importance weights.  As a byproduct of
    the calculations, we also obtain approximate standard errors for
    estimated predictive errors and for the comparison of predictive
    errors between models. The package also provides methods for using
    stacking and other model weighting techniques to average Bayesian
    predictive distributions.
License: GPL (>= 3)
URL: https://mc-stan.org/loo/, https://discourse.mc-stan.org
BugReports: https://github.com/stan-dev/loo/issues
Depends: R (>= 3.5)
Imports: checkmate, matrixStats (>= 0.52), parallel, posterior (>=
        1.7.0), stats
Suggests: bayesplot (>= 1.7.0), brms (>= 2.10.0), ggplot2, graphics,
        knitr, rmarkdown, rstan, rstanarm (>= 2.19.0), rstantools,
        spdep, testthat (>= 3.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/testthat/start-first: loo_subsampling_cases, loo_subsampling
Encoding: UTF-8
LazyData: TRUE
SystemRequirements: pandoc (>= 1.12.3), pandoc-citeproc
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-24 16:15:31 UTC; jgabry
Author: Aki Vehtari [aut],
  Jonah Gabry [cre, aut],
  Måns Magnusson [aut],
  Yuling Yao [aut],
  Paul-Christian Bürkner [aut],
  Topi Paananen [aut],
  Andrew Gelman [aut],
  Ben Goodrich [ctb],
  Juho Piironen [ctb],
  Bruno Nicenboim [ctb],
  Leevi Lindgren [ctb],
  Visruth Srimath Kandali [ctb],
  Florence Bockting [ctb]
Repository: CRAN
Date/Publication: 2026-06-26 08:20:08 UTC
