# extracting estimates by name is deprecated for loo objects

    Code
      loo1$elpd_loo
    Condition
      Warning:
      Accessing elpd_loo using '$' is deprecated and will be removed in a future release. Please extract the elpd_loo estimate from the 'estimates' component instead.
    Output
      [1] -83.58926

---

    Code
      loo1$se_elpd_loo
    Condition
      Warning:
      Accessing se_elpd_loo using '$' is deprecated and will be removed in a future release. Please extract the se_elpd_loo estimate from the 'estimates' component instead.
    Output
      [1] 4.283835

---

    Code
      loo1$p_loo
    Condition
      Warning:
      Accessing p_loo using '$' is deprecated and will be removed in a future release. Please extract the p_loo estimate from the 'estimates' component instead.
    Output
      [1] 3.328834

---

    Code
      loo1$se_p_loo
    Condition
      Warning:
      Accessing se_p_loo using '$' is deprecated and will be removed in a future release. Please extract the se_p_loo estimate from the 'estimates' component instead.
    Output
      [1] 1.152103

---

    Code
      loo1$looic
    Condition
      Warning:
      Accessing looic using '$' is deprecated and will be removed in a future release. Please extract the looic estimate from the 'estimates' component instead.
    Output
      [1] 167.1785

---

    Code
      loo1$se_looic
    Condition
      Warning:
      Accessing se_looic using '$' is deprecated and will be removed in a future release. Please extract the se_looic estimate from the 'estimates' component instead.
    Output
      [1] 8.567671

---

    Code
      loo1["elpd_loo"]
    Condition
      Warning:
      Accessing elpd_loo using '[' is deprecated and will be removed in a future release. Please extract the elpd_loo estimate from the 'estimates' component instead.
    Output
      $elpd_loo
      [1] -83.58926
      

---

    Code
      loo1["se_elpd_loo"]
    Condition
      Warning:
      Accessing se_elpd_loo using '[' is deprecated and will be removed in a future release. Please extract the se_elpd_loo estimate from the 'estimates' component instead.
    Output
      $se_elpd_loo
      [1] 4.283835
      

---

    Code
      loo1["p_loo"]
    Condition
      Warning:
      Accessing p_loo using '[' is deprecated and will be removed in a future release. Please extract the p_loo estimate from the 'estimates' component instead.
    Output
      $p_loo
      [1] 3.328834
      

---

    Code
      loo1["se_p_loo"]
    Condition
      Warning:
      Accessing se_p_loo using '[' is deprecated and will be removed in a future release. Please extract the se_p_loo estimate from the 'estimates' component instead.
    Output
      $se_p_loo
      [1] 1.152103
      

---

    Code
      loo1["looic"]
    Condition
      Warning:
      Accessing looic using '[' is deprecated and will be removed in a future release. Please extract the looic estimate from the 'estimates' component instead.
    Output
      $looic
      [1] 167.1785
      

---

    Code
      loo1["se_looic"]
    Condition
      Warning:
      Accessing se_looic using '[' is deprecated and will be removed in a future release. Please extract the se_looic estimate from the 'estimates' component instead.
    Output
      $se_looic
      [1] 8.567671
      

---

    Code
      loo1[["elpd_loo"]]
    Condition
      Warning:
      Accessing elpd_loo using '[[' is deprecated and will be removed in a future release. Please extract the elpd_loo estimate from the 'estimates' component instead.
    Output
      [1] -83.58926

---

    Code
      loo1[["se_elpd_loo"]]
    Condition
      Warning:
      Accessing se_elpd_loo using '[[' is deprecated and will be removed in a future release. Please extract the se_elpd_loo estimate from the 'estimates' component instead.
    Output
      [1] 4.283835

---

    Code
      loo1[["p_loo"]]
    Condition
      Warning:
      Accessing p_loo using '[[' is deprecated and will be removed in a future release. Please extract the p_loo estimate from the 'estimates' component instead.
    Output
      [1] 3.328834

---

    Code
      loo1[["se_p_loo"]]
    Condition
      Warning:
      Accessing se_p_loo using '[[' is deprecated and will be removed in a future release. Please extract the se_p_loo estimate from the 'estimates' component instead.
    Output
      [1] 1.152103

---

    Code
      loo1[["looic"]]
    Condition
      Warning:
      Accessing looic using '[[' is deprecated and will be removed in a future release. Please extract the looic estimate from the 'estimates' component instead.
    Output
      [1] 167.1785

---

    Code
      loo1[["se_looic"]]
    Condition
      Warning:
      Accessing se_looic using '[[' is deprecated and will be removed in a future release. Please extract the se_looic estimate from the 'estimates' component instead.
    Output
      [1] 8.567671

# extracting estimates by name is deprecated for waic objects

    Code
      waic1$elpd_waic
    Condition
      Warning:
      Accessing elpd_waic using '$' is deprecated and will be removed in a future release. Please extract the elpd_waic estimate from the 'estimates' component instead.
    Output
      [1] -83.53033

---

    Code
      waic1$se_elpd_waic
    Condition
      Warning:
      Accessing se_elpd_waic using '$' is deprecated and will be removed in a future release. Please extract the se_elpd_waic estimate from the 'estimates' component instead.
    Output
      [1] 4.258048

---

    Code
      waic1$p_waic
    Condition
      Warning:
      Accessing p_waic using '$' is deprecated and will be removed in a future release. Please extract the p_waic estimate from the 'estimates' component instead.
    Output
      [1] 3.269898

---

    Code
      waic1$se_p_waic
    Condition
      Warning:
      Accessing se_p_waic using '$' is deprecated and will be removed in a future release. Please extract the se_p_waic estimate from the 'estimates' component instead.
    Output
      [1] 1.124365

---

    Code
      waic1$waic
    Condition
      Warning:
      Accessing waic using '$' is deprecated and will be removed in a future release. Please extract the waic estimate from the 'estimates' component instead.
    Output
      [1] 167.0607

---

    Code
      waic1$se_waic
    Condition
      Warning:
      Accessing se_waic using '$' is deprecated and will be removed in a future release. Please extract the se_waic estimate from the 'estimates' component instead.
    Output
      [1] 8.516096

---

    Code
      waic1["elpd_waic"]
    Condition
      Warning:
      Accessing elpd_waic using '[' is deprecated and will be removed in a future release. Please extract the elpd_waic estimate from the 'estimates' component instead.
    Output
      $elpd_waic
      [1] -83.53033
      

---

    Code
      waic1["se_elpd_waic"]
    Condition
      Warning:
      Accessing se_elpd_waic using '[' is deprecated and will be removed in a future release. Please extract the se_elpd_waic estimate from the 'estimates' component instead.
    Output
      $se_elpd_waic
      [1] 4.258048
      

---

    Code
      waic1["p_waic"]
    Condition
      Warning:
      Accessing p_waic using '[' is deprecated and will be removed in a future release. Please extract the p_waic estimate from the 'estimates' component instead.
    Output
      $p_waic
      [1] 3.269898
      

---

    Code
      waic1["se_p_waic"]
    Condition
      Warning:
      Accessing se_p_waic using '[' is deprecated and will be removed in a future release. Please extract the se_p_waic estimate from the 'estimates' component instead.
    Output
      $se_p_waic
      [1] 1.124365
      

---

    Code
      waic1["waic"]
    Condition
      Warning:
      Accessing waic using '[' is deprecated and will be removed in a future release. Please extract the waic estimate from the 'estimates' component instead.
    Output
      $waic
      [1] 167.0607
      

---

    Code
      waic1["se_waic"]
    Condition
      Warning:
      Accessing se_waic using '[' is deprecated and will be removed in a future release. Please extract the se_waic estimate from the 'estimates' component instead.
    Output
      $se_waic
      [1] 8.516096
      

---

    Code
      waic1[["elpd_waic"]]
    Condition
      Warning:
      Accessing elpd_waic using '[[' is deprecated and will be removed in a future release. Please extract the elpd_waic estimate from the 'estimates' component instead.
    Output
      [1] -83.53033

---

    Code
      waic1[["se_elpd_waic"]]
    Condition
      Warning:
      Accessing se_elpd_waic using '[[' is deprecated and will be removed in a future release. Please extract the se_elpd_waic estimate from the 'estimates' component instead.
    Output
      [1] 4.258048

---

    Code
      waic1[["p_waic"]]
    Condition
      Warning:
      Accessing p_waic using '[[' is deprecated and will be removed in a future release. Please extract the p_waic estimate from the 'estimates' component instead.
    Output
      [1] 3.269898

---

    Code
      waic1[["se_p_waic"]]
    Condition
      Warning:
      Accessing se_p_waic using '[[' is deprecated and will be removed in a future release. Please extract the se_p_waic estimate from the 'estimates' component instead.
    Output
      [1] 1.124365

---

    Code
      waic1[["waic"]]
    Condition
      Warning:
      Accessing waic using '[[' is deprecated and will be removed in a future release. Please extract the waic estimate from the 'estimates' component instead.
    Output
      [1] 167.0607

---

    Code
      waic1[["se_waic"]]
    Condition
      Warning:
      Accessing se_waic using '[[' is deprecated and will be removed in a future release. Please extract the se_waic estimate from the 'estimates' component instead.
    Output
      [1] 8.516096

