# psislw handles special cases, throws appropriate errors/warnings

    Code
      psis <- psislw(x[, 1], wcp = 0.01)
    Condition
      Warning in `psislw()`:
      'psislw' is deprecated.
      Use 'psis' instead.
      See help("Deprecated")
      Warning:
      All tail values are the same. Weights are truncated but not smoothed.
      Warning:
      Some Pareto k diagnostic values are too high. See help('pareto-k-diagnostic') for details.

