# gpdfit returns correct result

    WAoAAAACAAQFAAACAwAAAAIOAAAAAj+cD4qKVTgaP/BK8xJCK3sAAAQCAAAAAQAEAAkAAAAF
    bmFtZXMAAAAQAAAAAgAEAAkAAAABawAEAAkAAAAFc2lnbWEAAAD+

---

    WAoAAAACAAQFAAACAwAAAAIOAAAAAj+yA4g2tkbvP/BK8xJCK3sAAAQCAAAAAQAEAAkAAAAF
    bmFtZXMAAAAQAAAAAgAEAAkAAAABawAEAAkAAAAFc2lnbWEAAAD+

---

    WAoAAAACAAQFAAACAwAAAAIOAAAAAj+yA5BUlFrHP/BK8oexSVIAAAQCAAAAAQAEAAkAAAAF
    bmFtZXMAAAAQAAAAAgAEAAkAAAABawAEAAkAAAAFc2lnbWEAAAD+

