# loo_predictive_metric is equal to snapshot

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP+b6DHwJlO4AAAAOAAAAAT+0VQV434B0
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP/c/cc5N6ckAAAAOAAAAAT/C02/w8SU2
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP+r8D5W4BOIAAAAOAAAAAT+07COl+XlU
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP/qvkDt3DvwAAAAOAAAAAT/BcF2FCRTJ
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP+bBWsjIsVUAAAAOAAAAAT/BpKrAKkv4
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABQAZBDZS19iwAAAAOAAAAAT/dFfIrJ59T
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP9gAAAAAAAAAAAAOAAAAAT+16K3SNqWP
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP9QAAAAAAAAAAAAOAAAAAT+0+ea7xOyz
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP9aw32sN9rEAAAAOAAAAAT+uapXy8Hyq
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

---

    WAoAAAACAAQFAAACAwAAAAITAAAAAgAAAA4AAAABP+AAAAAAAAAAAAAOAAAAAQAAAAAAAAAA
    AAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAIABAAJAAAACGVzdGltYXRlAAQACQAAAAJz
    ZQAAAP4=

