% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/loo_subsample.R
\name{obs_idx}
\alias{obs_idx}
\title{Get observation indices used in subsampling}
\usage{
obs_idx(x, rep = TRUE)
}
\arguments{
\item{x}{A \code{psis_loo_ss} object.}

\item{rep}{If sampling with replacement is used, an observation can have
multiple samples and these are then repeated in the returned object if
\code{rep=TRUE} (e.g., a vector \code{c(1,1,2)} indicates that observation 1 has been
subsampled two times). If \code{rep=FALSE} only the unique indices are returned.}
}
\value{
An integer vector.
}
\description{
Get observation indices used in subsampling
}
