% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/psislw.R
\name{psislw}
\alias{psislw}
\title{Pareto smoothed importance sampling (deprecated, old version)}
\usage{
psislw(
  lw,
  wcp = 0.2,
  wtrunc = 3/4,
  cores = getOption("mc.cores", 1),
  llfun = NULL,
  llargs = NULL,
  ...
)
}
\arguments{
\item{lw}{A matrix or vector of log weights. For computing LOO, \code{lw = -log_lik}, the \emph{negative} of an \eqn{S} (simulations) by \eqn{N} (data
points) pointwise log-likelihood matrix.}

\item{wcp}{The proportion of importance weights to use for the generalized
Pareto fit. The \code{100*wcp}\\% largest weights are used as the sample
from which to estimate the parameters of the generalized Pareto
distribution.}

\item{wtrunc}{For truncating very large weights to \eqn{S}^\code{wtrunc}. Set
to zero for no truncation.}

\item{cores}{The number of cores to use for parallelization. This defaults to
the option \code{mc.cores} which can be set for an entire R session by
\code{options(mc.cores = NUMBER)}, the old option \code{loo.cores} is now
deprecated but will be given precedence over \code{mc.cores} until it is
removed. \strong{As of version 2.0.0, the default is now 1 core if
\code{mc.cores} is not set, but we recommend using as many (or close to as
many) cores as possible.}}

\item{llfun, llargs}{See \code{\link[=loo.function]{loo.function()}}.}

\item{...}{Ignored when \code{psislw()} is called directly. The \code{...} is
only used internally when \code{psislw()} is called by the \code{\link[=loo]{loo()}}
function.}
}
\value{
A named list with components \code{lw_smooth} (modified log weights) and
\code{pareto_k} (estimated generalized Pareto shape parameter(s) k).
}
\description{
As of version \verb{2.0.0} this function is \strong{deprecated}. Please use the
\code{\link[=psis]{psis()}} function for the new PSIS algorithm.
}
\references{
Vehtari, A., Gelman, A., and Gabry, J. (2017). Practical Bayesian model
evaluation using leave-one-out cross-validation and WAIC.
\emph{Statistics and Computing}. 27(5), 1413--1432. doi:10.1007/s11222-016-9696-4
(\href{https://link.springer.com/article/10.1007/s11222-016-9696-4}{journal version},
\href{https://arxiv.org/abs/1507.04544}{preprint arXiv:1507.04544}).

Vehtari, A., Simpson, D., Gelman, A., Yao, Y., and Gabry, J. (2024).
Pareto smoothed importance sampling. \emph{Journal of Machine Learning Research},
25(72):1-58.
\href{https://jmlr.org/papers/v25/19-556.html}{PDF}
}
\seealso{
\link{pareto-k-diagnostic} for PSIS diagnostics.
}
