% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print.R
\name{print.loo}
\alias{print.loo}
\alias{print.waic}
\alias{print.psis_loo}
\alias{print.importance_sampling_loo}
\alias{print.psis_loo_ap}
\alias{print.psis}
\alias{print.importance_sampling}
\alias{print.kfold}
\title{Print methods}
\usage{
\method{print}{loo}(x, digits = 1, ...)

\method{print}{waic}(x, digits = 1, ...)

\method{print}{psis_loo}(x, digits = 1, plot_k = FALSE, ...)

\method{print}{importance_sampling_loo}(x, digits = 1, plot_k = FALSE, ...)

\method{print}{psis_loo_ap}(x, digits = 1, plot_k = FALSE, ...)

\method{print}{psis}(x, digits = 1, plot_k = FALSE, ...)

\method{print}{importance_sampling}(x, digits = 1, plot_k = FALSE, ...)

\method{print}{kfold}(x, digits = 1, plot_k = FALSE, ...)
}
\arguments{
\item{x}{An object returned by \code{\link[=loo]{loo()}}, \code{\link[=psis]{psis()}}, or \code{\link[=waic]{waic()}}.}

\item{digits}{An integer passed to \code{\link[base:round]{base::round()}}.}

\item{...}{Arguments passed to \code{\link[=plot.psis_loo]{plot.psis_loo()}} if \code{plot_k} is
\code{TRUE}.}

\item{plot_k}{Logical. If \code{TRUE} the estimates of the Pareto shape
parameter \eqn{k} are plotted. Ignored if \code{x} was generated by
\code{\link[=waic]{waic()}}. To just plot \eqn{k} without printing use the
\link[=pareto-k-diagnostic]{plot()} method for 'loo' objects.}
}
\value{
\code{x}, invisibly.
}
\description{
Print methods
}
\seealso{
\link{pareto-k-diagnostic}
}
