% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/loo_subsample.R
\name{.ndraws}
\alias{.ndraws}
\alias{.ndraws.matrix}
\alias{.ndraws.default}
\title{The number of posterior draws in a draws object.}
\usage{
.ndraws(x)

\method{.ndraws}{matrix}(x)

\method{.ndraws}{default}(x)
}
\arguments{
\item{x}{A draws object with posterior draws.}
}
\value{
An integer with the number of draws.
}
\description{
The number of posterior draws in a draws object.
}
\details{
This is a generic function to return the total number of draws from
an arbitrary draws objects. The function is internal and should only be
used by developers to enable \code{\link[=loo_subsample]{loo_subsample()}} for arbitrary draws objects.
}
\keyword{internal}
