% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/loo.R
\name{old-extractors}
\alias{old-extractors}
\alias{[.loo}
\alias{[[.loo}
\alias{$.loo}
\title{Extractor methods}
\usage{
\method{[}{loo}(x, i)

\method{[[}{loo}(x, i, exact = TRUE)

\method{$}{loo}(x, name)
}
\arguments{
\item{x, i, exact, name}{See \link{Extract}.}
}
\description{
These are only defined in order to deprecate with a warning (rather than
remove and break backwards compatibility) the old way of accessing the point
estimates in a \code{"psis_loo"} or \code{"psis"} object. The new way as of
v2.0.0 is to get them from the \code{"estimates"} component of the object.
}
\keyword{internal}
