% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print.R
\name{print_dims}
\alias{print_dims}
\alias{print_dims.importance_sampling}
\alias{print_dims.psis_loo}
\alias{print_dims.importance_sampling_loo}
\alias{print_dims.waic}
\alias{print_dims.kfold}
\alias{print_dims.psis_loo_ss}
\title{Print dimensions of log-likelihood or log-weights matrix}
\usage{
print_dims(x, ...)

\method{print_dims}{importance_sampling}(x, ...)

\method{print_dims}{psis_loo}(x, ...)

\method{print_dims}{importance_sampling_loo}(x, ...)

\method{print_dims}{waic}(x, ...)

\method{print_dims}{kfold}(x, ...)

\method{print_dims}{psis_loo_ss}(x, ...)
}
\arguments{
\item{x}{The object returned by \code{\link[=psis]{psis()}}, \code{\link[=loo]{loo()}}, or \code{\link[=waic]{waic()}}.}

\item{...}{Ignored.}
}
\description{
Print dimensions of log-likelihood or log-weights matrix
}
\keyword{internal}
