% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/importance_sampling.R
\name{weights.importance_sampling}
\alias{weights.importance_sampling}
\title{Extract importance sampling weights}
\usage{
\method{weights}{importance_sampling}(object, ..., log = TRUE, normalize = TRUE)
}
\arguments{
\item{object}{An object returned by \code{\link[=psis]{psis()}}, \code{\link[=tis]{tis()}}, or \code{\link[=sis]{sis()}}.}

\item{...}{Ignored.}

\item{log}{Should the weights be returned on the log scale? Defaults to
\code{TRUE}.}

\item{normalize}{Should the weights be normalized? Defaults to \code{TRUE}.}
}
\value{
The \code{weights()} method returns an object with the same dimensions as
the \code{log_weights} component of \code{object}. The \code{normalize} and \code{log}
arguments control whether the returned weights are normalized and whether
or not to return them on the log scale.
}
\description{
Extract importance sampling weights
}
\examples{
# See the examples at help("psis")

}
