% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/loo_subsample.R
\name{nobs.psis_loo_ss}
\alias{nobs.psis_loo_ss}
\title{The number of observations in a \code{psis_loo_ss} object.}
\usage{
\method{nobs}{psis_loo_ss}(object, ...)
}
\arguments{
\item{object}{a \code{psis_loo_ss} object.}

\item{...}{Currently unused.}
}
\description{
The number of observations in a \code{psis_loo_ss} object.
}
